.\" @project        The CERN Tape Archive (CTA)
.\" @copyright      Copyright(C) 2008-2021 CERN
.\" @license        This program is free software: you can redistribute it and/or modify
.\"                 it under the terms of the GNU General Public License as published by
.\"                 the Free Software Foundation, either version 3 of the License, or
.\"                 (at your option) any later version.
.\"
.\"                 This program is distributed in the hope that it will be useful,
.\"                 but WITHOUT ANY WARRANTY; without even the implied warranty of
.\"                 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
.\"                 GNU General Public License for more details.
.\"
.\"                 You should have received a copy of the GNU General Public License
.\"                 along with this program.  If not, see <http://www.gnu.org/licenses/>.
.TH NETREAD "3castor" "$Date: 2008/05/07 14:53:22 $" CASTOR "Common Library Functions"
.SH NAME
netread \- receive a message from a socket
.SH SYNOPSIS
\fB#include "net.h"\fR
.sp
.BI "int netread (int " s ,
.BI "char *" buf ,
.BI "int " nbytes );
.sp
.BI "ssize_t netread_timeout (int " s ,
.BI "void *" buf ,
.BI "size_t " nbytes ,
.BI "int " timeout );
.SH DESCRIPTION
.B netread
receives a message from a socket.
It overcomes the message fragmentation problem and always waits for all
requested bytes to arrive or a timeout/error occurs.
.SH RETURN VALUE
This routine returns the number of bytes if the operation was successful,
0 if the connection was closed by the remote end
or -1 if the operation failed. In the latter case,
.B serrno
is set appropriately.
.SH ERRORS
.TP 1.2i
.B EINTR
The function was interrupted by a signal.
.TP
.B EBADF
.I s
is not a valid descriptor.
.TP
.B EAGAIN
The socket is non-blocking and there is no message available.
.TP
.B EFAULT
.I buf
is not a valid pointer.
.TP
.B EINVAL
.I nbytes
is negative or zero.
.TP
.B ENOTSOCK
.I s
is not a socket.
.TP
.B SECONNDROP
Connection closed by remote end.
.TP
.B SETIMEDOUT
Timed out.
.SH SEE ALSO
.BR recv(2)
.SH AUTHOR
\fBCASTOR\fP Team <castor.support@cern.ch>
